from mock import MagicMock, patch
import datetime
import json
import os.path
import unittest
from psqa.util.extractor import JenkinsJob, JenkinsBuild

DATA_PATH = "psqa/tests/data"


class JenkinsJobTestCase(unittest.TestCase):
    """Unit tests for class JenkinsJob"""

    def setUp(self):
        url = "http://10.97.0.6:8080/job/nux-mbs-autolanding/"
        data = self._get_data("nux-mbs-autolanding.json")
        self.job = JenkinsJob(url, data)

    def _get_data(self, filename):
        return json.loads(self._get_text(filename))

    def _get_text(self, filename):
        with open(os.path.join(DATA_PATH, filename)) as in_file:
            return in_file.read()

    def test_data_none(self):
        url = "http://10.97.0.6:8080/job/compiz-mbs-autolanding/"
        data = self._get_data("compiz-mbs-autolanding.json")
        get_data_mock = MagicMock()
        get_data_mock.side_effect = [data]
        value = None
        with patch('psqa.util.extractor.get_json_from_url', get_data_mock):
            build = JenkinsBuild(url)
            value = "%s" % (build)
        self.assertEqual(len(value), 31500)

    def test_name(self):
        self.assertEqual(self.job.name, "nux-mbs-autolanding")

    def test_builds(self):
        builds = None
        get_data_mock = MagicMock()
        data = self._get_data("nux-mbs-autolanding-98.json")
        get_data_mock.return_value = data
        with patch('psqa.util.extractor.get_json_from_url', get_data_mock):
            builds = self.job.builds
        self.assertEqual(len(builds), 101)

    def test_downstream_jobs(self):
        jobs = None
        name = None
        get_data_mock = MagicMock()
        data = self._get_data("compiz-mbs-autolanding.json")
        get_data_mock.side_effect = [data, data, data]
        with patch('psqa.util.extractor.get_json_from_url', get_data_mock):
            jobs = self.job.downstream_jobs
            name = jobs[0].name
        self.assertEqual(len(jobs), 3)
        self.assertEqual(name, "compiz-mbs-autolanding")

    def test_parameters(self):
        self.assertEqual(len(self.job.parameters), 19)
        self.assertEqual(self.job.parameters['project'], 'nux')
        self.assertEqual(self.job.parameters['target_branch'], 'lp:nux')

    def test_buildable(self):
        self.assertEqual(self.job.buildable, True)

    def test_in_queue(self):
        self.assertEqual(self.job.in_queue, False)

    def test_last_build(self):
        self.assertEqual(self.job.last_build, 101)

    def test_last_completed_build(self):
        self.assertEqual(self.job.last_completed_build, 101)

    def test_last_failed_build(self):
        self.assertEqual(self.job.last_failed_build, 101)

    def test_last_successful_build(self):
        self.assertEqual(self.job.last_successful_build, 99)
