from mock import MagicMock, patch
import datetime
import json
import os.path
import unittest
from psqa.util.extractor import JenkinsTestReport

"""Tests for module JenkinsTestReport"""

DATA_PATH = "psqa/tests/data"
DATA_FILE = "nux-mbs-autolanding-98-amd64-testReport.json"


class JenkinsRunTestCase(unittest.TestCase):
    """Unit tests for class JenkinsTestReport"""

    def _get_data(self, filename):
        with open(os.path.join(DATA_PATH, filename)) as in_file:
            return json.loads(in_file.read())

    def test_init_with_data(self):
        url = 'http://10.97.0.6:8080/job/nux-mbs-autolanding/build=pbuilder,distribution=raring,flavor=amd64/98/testReport'
        data = self._get_data(DATA_FILE)
        test_report = JenkinsTestReport(url, data)
        self.assertEqual(test_report.fail_count, 0)
        self.assertEqual(test_report.pass_count, 131)
        self.assertEqual(test_report.skip_count, 0)
        self.assertEqual(len(test_report.children), 0)
        self.assertEqual(test_report.duration.microseconds, 36)

    def test_init_no_data(self):
        test_report = JenkinsTestReport()
        self.assertEqual(test_report.fail_count, 0)
        self.assertEqual(test_report.pass_count, 0)
        self.assertEqual(test_report.skip_count, 0)
        self.assertEqual(len(test_report.children), 0)

    def test_add(self):
        data = self._get_data(DATA_FILE)
        url = 'http://10.97.0.6:8080/job/nux-mbs-autolanding/build=pbuilder,distribution=raring,flavor=amd64/98/testReport'
        test_report_amd64 = JenkinsTestReport(url, data)
        url = 'http://10.97.0.6:8080/job/nux-mbs-autolanding/build=pbuilder,distribution=raring,flavor=armhf/98/testReport'
        test_report_armhf = JenkinsTestReport(url, data)
        url = 'http://10.97.0.6:8080/job/nux-mbs-autolanding/build=pbuilder,distribution=raring,flavor=i386/98/testReport'
        test_report_i386 = JenkinsTestReport(url, data)
        test_report = JenkinsTestReport()
        test_report.add(test_report_amd64)
        test_report.add(test_report_armhf)
        test_report.add(test_report_i386)
        self.assertEqual(test_report.fail_count, 0)
        self.assertEqual(test_report.pass_count, 393)
        self.assertEqual(test_report.skip_count, 0)
        self.assertEqual(len(test_report.children), 3)
