from mock import call, MagicMock, patch
import json
import os.path
import unittest
from psqa.util.extractor import get_json_from_url, get_text_from_url

"""Tests for module JenkinsUtilites"""

DATA_PATH = "tests/data"


class JenkinsUtilitiesTestCase(unittest.TestCase):
    """Unit tests for JenkinsUtilities methods"""

    def setUp(self):
        self.get_mock = MagicMock(return_value=type('fake_request',
                                                    (object,),
                                                    {'status_code': 200,
                                                     'text': '{"value": 42}'}))

    def test_get_json_from_url(self):
        url = "http://localhost/foo/"
        data = None
        with patch('requests.get', self.get_mock):
            data = get_json_from_url(url)
        self.assertEqual(data['value'], 42)
        self.assertEqual(self.get_mock.call_args, call(url + "/api/json"))

    def test_get_json_from_url_none(self):
        url = "http://localhost/foo/"
        mock = MagicMock(return_value=type('fake_request',
                                           (object,),
                                           {'status_code': 404,
                                            'text': 'null'}))
        with patch('requests.get', mock):
            with self.assertRaises(EnvironmentError) as err:
                get_json_from_url(url)
            self.assertEqual("No json data at http://localhost/foo//api/json",
                             "%s" % (err.exception))

    def test_get_text_from_url(self):
        url = "http://localhost/foo/"
        data = None
        with patch('requests.get', self.get_mock):
            data = get_text_from_url(url)
        self.assertEqual(data, '{"value": 42}')
        self.assertEqual(self.get_mock.call_args, call(url))

    def test_get_text_from_url_none(self):
        url = "http://localhost/foo/"
        mock = MagicMock(return_value=type('fake_request',
                                           (object,),
                                           {'status_code': 404,
                                            'text': 'null'}))
        with patch('requests.get', mock):
            with self.assertRaises(EnvironmentError) as err:
                get_text_from_url(url)
            self.assertEqual("No data at http://localhost/foo/",
                             "%s" % (err.exception))
