import logging
from django.http import HttpResponse
from django.template import (Context, loader)
from psqa.models import (PsqaProject,
                         JenkinsJob,
                         JenkinsBuild,
                         JenkinsRun,
                         JenkinsResult)

logger = logging.getLogger('helipad')

def index(request):
    t = loader.get_template('main.html')
    c = Context({ })
    return HttpResponse(t.render(c))


def build(request, job_name, build_number):
    jenkins_build = JenkinsBuild.objects.get(jenkins_job__name=job_name,
                                             number=build_number)
    runs = JenkinsRun.objects.filter(jenkins_build=jenkins_build)
    t = loader.get_template('build.html')
    c = Context({'build': jenkins_build,
                 'runs': runs,})
    return HttpResponse(t.render(c))


BRANCH_FILTER_TYPES = ['all',
                       'autolanding',
                       'ci',
                       'daily',
                       'coverity',]
def job_list(request):
    show_filter = request.GET.get('show')
    logger.debug("Filter: %s" % show_filter)
    if show_filter is None or show_filter not in BRANCH_FILTER_TYPES:
        show_filter = 'all'

    job_list = JenkinsJob.objects.all().order_by('-name')
    if show_filter == 'all':
        out_list = job_list
    else:
        out_list = []
        for j in job_list:
            if j.name.endswith(show_filter):
                out_list.append(j)

    # TODO Remove fake data
    for j in out_list:
        j.series = 'raring'
        j.arch = 'amd64, armhf, i386'
        j.last_run_data = ''
        j.build_count = 40
        j.duration = 1200
        j.test_count = 120
        j.coverage_rate = 0.55
        j.coverage_rate_pct = 55
        j.bug_count = 0

    t = loader.get_template('job_list.html')
    c = Context({
        'job_list': out_list,
    })
    return HttpResponse(t.render(c))

BUILD_FILTER_TYPES = ['all',
                      'passed',
                      'unstable',
                      'failed',
                     ]
def job(request, job_name):
    show_filter = request.GET.get('show')
    logger.debug("Filter: %s" % show_filter)
    job = JenkinsJob.objects.get(name=job_name)
    build_list = JenkinsBuild.objects.filter(jenkins_job=job)
    build_filter_list = JenkinsResult.objects.all()
    if show_filter is None or show_filter not in BUILD_FILTER_TYPES:
        show_filter = 'all'
    for b in build_list:
        # TODO Remove fake data
        url = b.url[:-1]
        url = url[url.rfind('/') + 1:]
        b.number = int(url)
        b.status = 'passed'
        if b.number % 3 == 0:
            b.status = 'unstable'
        if b.number % 5 == 0:
            b.status = 'failed'

    if show_filter == 'all':
        out_list = build_list
    else:
        out_list = []
        for b in build_list:
            if b.status == show_filter:
                out_list.append(b)

    t = loader.get_template('job.html')
    c = Context({
        'job_name': job_name,
        'build_list': out_list,
    })
    return HttpResponse(t.render(c))


def mk_branch(name, revno, rev_date, series, package, package_date):
    b = type('Branch', (object,), dict(name=name,
                                       revno=revno,
                                       rev_date=rev_date,
                                       series=series,
                                       package=package,
                                       package_date=package_date))
    return b


def branch_list(request):
    branch_list = []
    # TODO Remove fake data
    branch_list.append(mk_branch('lp:unity', 1234, '2/12/2013', 'raring',
                                 '6.10.blah', '2/10/2013'))
    branch_list.append(mk_branch('lp:nux', 2341, '2/12/2013', 'raring',
                                 '2.10.0.blah', '2/08/2013'))
    branch_list.append(mk_branch('lp:compiz', 3412, '2/2/2013', 'raring',
                                 '1:9.9.9.blah', '1/12/2013'))
    out_list = branch_list

    t = loader.get_template('branch_list.html')
    c = Context({
        'branch_list': out_list,
    })
    return HttpResponse(t.render(c))


def project_list(request):
    project_list = PsqaProject.objects.all()
    t = loader.get_template('project_list.html')
    c = Context({'project_list': project_list})
    return HttpResponse(t.render(c))


def integration(request):
    return HttpResponse("Hello, world. You're at the integration index.")

